
<h2> Hello, I'm <b>XNOXS</b> 👋</h2>

<img align='right' src="https://github-readme-stats.vercel.app/api/top-langs/?username=xnoxs-dev&theme=codeSTACKr" width="350">

[![Github: xnoxs](https://img.shields.io/github/followers/xnoxs-dev?style=social)](https://github.com/xnoxs-dev)
[![Gmail: xnoxs](https://img.shields.io/badge/Gmail-xnoxs-green?style=social&logo=gmail)](mailto:bintangpamungkas2580@gmail.com)
[![Telegram: xnoxs](https://img.shields.io/badge/Telegram-xnoxs-green?style=social&logo=Telegram)](https://t.me/PetapaGenit2)
<br>

![Donation: xnoxs](https://img.shields.io/badge/💰-Donation-orange?style=flat-square)
<br>
![BTC: xnoxs](https://img.shields.io/badge/BTC-18jswG2t9EZrnHju5dyiYw1yGbkcrTSgJg-orange?style=flat-square&logo=bitcoin)
<br>
![Paypal: xnoxsl](https://img.shields.io/badge/Paypal-khaerudin2119@gmail.com-orange?style=flat-square&logo=paypal)
<br>
![Dana: xnoxs](https://img.shields.io/badge/Dana-085811188821-orange?style=flat-square&logo=idr)
<br>
<img align='left' src="https://github-readme-stats.vercel.app/api?username=xnoxs-dev&show_icons=true&theme=codeSTACKr" width="350">

<!--[tema readme stats] -->
<!--https://github.com/anuraghazra/github-readme-stats/blob/master/themes/README.md-->
